<?php

    namespace FederationLib\Interfaces;

    use FederationLib\Objects\Client;
    use FederationLib\Objects\Peer;
    use FederationLib\Objects\Standard\PeerMetadata\TelegramUserMetadata;

    interface PeerMetadataManagerInterface
    {
        /**
         * Intelligently syncs the metadata of the given federated address, this will ignore raw metadata & use
         * data from the given $client_uuid
         *
         * @param Client|string $client_uuid
         * @param TelegramUserMetadata $telegram_user_metadata
         * @return string
         */
        public function syncMetadata(Client|string $client_uuid, TelegramUserMetadata $telegram_user_metadata): string;

        /**
         * Registers the metadata of the given federated address, this will ignore raw metadata & use data from the
         * given $client_uuid
         *
         * @param Client|string $client_uuid
         * @param TelegramUserMetadata $telegram_user_metadata
         * @return string
         */
        public function registerMetadata(Client|string $client_uuid, TelegramUserMetadata $telegram_user_metadata): string;

        /**
         * Returns the metadata of the given federated address, this returns the full raw metadata
         *
         * @param Peer|string $federated_address
         * @return TelegramUserMetadata
         */
        public function getMetadata(Peer|string $federated_address): TelegramUserMetadata;
    }